@@ -476,11 +476,15 @@ _pygi_g_type_info_check_object (GITypeInfo *type_info,
                               PyString_AS_STRING (upper_str));
 #else
                 {
-                    PyObject *lower_pybytes_obj = PyUnicode_AsUTF8String (lower_str);
-                    if (!lower_pybytes_obj)
-                        goto utf8_fail;
+                    PyObject *lower_pybytes_obj;
+                    PyObject *upper_pybytes_obj;
 
-                    PyObject *upper_pybytes_obj = PyUnicode_AsUTF8String (upper_str);                    
+                    lower_pybytes_obj = PyUnicode_AsUTF8String (lower_str);
+                    if (!lower_pybytes_obj) {
+                        goto utf8_fail;
+                    }
+
+                    upper_pybytes_obj = PyUnicode_AsUTF8String (upper_str);
                     if (!upper_pybytes_obj) {
                         Py_DECREF(lower_pybytes_obj);
                         goto utf8_fail;
@@ -803,6 +807,10 @@ _pygi_argument_to_array (GIArgument  *arg,
             } else {
                 length = g_type_info_get_array_fixed_size (type_info);
                 if (length < 0) {
+                    gint length_arg_pos;
+                    GIArgInfo length_arg_info;
+                    GITypeInfo length_type_info;
+
                     if (G_UNLIKELY (args == NULL)) {
                         g_critical ("Unable to determine array length for %p",
                                     arg->v_pointer);
@@ -810,9 +818,6 @@ _pygi_argument_to_array (GIArgument  *arg,
                         *out_free_array = TRUE;
                         return g_array;
                     }
-                    gint length_arg_pos;
-                    GIArgInfo length_arg_info;
-                    GITypeInfo length_type_info;
 
                     length_arg_pos = g_type_info_get_array_length (type_info);
                     g_assert (length_arg_pos >= 0);
@@ -1862,16 +1867,13 @@ _pygi_argument_to_object (GIArgument  *arg,
                       break;
                     }
 
-                    /* since we will unref the object when the
-                     * wrapper is destroyed and we don't want
-                     * GTK removing the object while the
-                     * wrapper is live, we take a gobject reference
-                     * when one is not transfered to us
+                    /* Only sink incoming objects if the transfer everything.
+                     * See: https://bugzilla.gnome.org/show_bug.cgi?id=675726
                      */
-                    if (transfer == GI_TRANSFER_NOTHING)
-                        g_object_ref (G_OBJECT(arg->v_pointer));
+                    object = pygobject_new_full (arg->v_pointer,
+                                                 /*sink=*/ transfer == GI_TRANSFER_EVERYTHING,
+                                                 /*type=*/ NULL);
 
-                    object = pygobject_new (arg->v_pointer);
                     break;
                 default:
                     g_assert_not_reached();
