@@ -27,11 +27,11 @@
 #include "pygi-foreign.h"
 #include "pygi-closure.h"
 #include "pygi-ccallback.h"
-#include "pygi-callbacks.h"
 #include "pygi-property.h"
 #include "pygi-signal-closure.h"
 #include "pygi-invoke.h"
 #include "pygi-cache.h"
+#include "pygi-source.h"
 
 G_BEGIN_DECLS
 #if PY_VERSION_HEX >= 0x03000000
